.. pydicom documentation master file, created by
   sphinx-quickstart on Sat Feb 20 23:28:19 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=====================
pydicom documentation
=====================

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Getting started

   getting_started.rst

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation

   pydicom_user_guide.rst
   ref_guide.rst
   api_ref.rst

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Examples

   auto_examples/index

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Additional Information

   release-notes

`Getting started <getting_started.html>`_
-----------------------------------------

Information to install, test, and contribute to the package.

`User Guide <pydicom_user_guide.html>`_
---------------------------------------

The main documentation. This contains an in-depth description of all
core elements of pydicom and how to apply them.

`Reading and writing DICOM files <ref_guide.html>`_
-------------------------------------------------------------------------

The API documentation of the most commonly used functions for reading
and writing DICOM files.

`API Reference <api_ref.html>`_
-----------------------------------

The API documentation of all functions and classes, as given in the
docstring. The API documents expected types and allowed features for
all functions, and all parameters available for the core elements.

`Examples <auto_examples/index.html>`_
--------------------------------------

A set of examples illustrating the use of the different core elements. It
complements the `User Guide <pydicom_user_guide.html>`_.

`What's new <release-notes.html>`_
------------------------------

Log of the pydicom history.
